# Mapper

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**dont_map_event_to_labels** | **bool** | DontMapEventToLabels by default we will map all the fields of the event to incident labels | [optional] 
**internal_mapping** | [**dict(str, AdvanceArg)**](AdvanceArg.md) |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


